Struct libp2p_deflate::DeflateConfig [−][src]
pub struct DeflateConfig { /* fields omitted */ }Trait Implementations
type Output = DeflateOutput<C>
type Output = DeflateOutput<C>Output after the upgrade has been successfully negotiated and the handshake performed.
Future that performs the handshake with the remote.
After we have determined that the remote supports one of the protocols we support, this method is called to start the handshake. Read more
type Output = DeflateOutput<C>
type Output = DeflateOutput<C>Output after the upgrade has been successfully negotiated and the handshake performed.
Future that performs the handshake with the remote.
After we have determined that the remote supports one of the protocols we support, this method is called to start the handshake. Read more
type Info = &'static [u8]
type Info = &'static [u8]Opaque type representing a negotiable protocol.
Returns the list of protocols that are supported. Used during the negotiation process.